==> ktp-accounts-kcm-22.04.2.tar.xz: ktp-accounts-kcm-22.04.2/plugins/idle/ktpaccountskcm_plugin_idle.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Idle connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći Idle menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració del compte personalitzat per a comptes que usen el gestor de connexions Idle.
Comment[ca@valencia]=Interfície d'usuari de configuració del compte personalisat per a comptes que utilisen el gestor de connexions Idle.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Idle.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Idle.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Idle-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Idle.
Comment[en_GB]=Custom account configuration user interface for accounts using the Idle connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Idle.
Comment[et]=Idle ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[eu]=Kontuak konfiguratzeko norberak finkaturiko erabiltzaile interfazea «Idle» konexio kudeatzailea erabiltzen duten kontuetarako.
Comment[fi]=Idle-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « Idle ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Idle.
Comment[hu]=Egyedi beállítófelület az Idle kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Idle.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Idle.
Comment[kk]=Idle байланыс менеджерін қолданатын тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី​ផ្ទាល់ខ្លួន​សម្រាប់​គណនី​ដោយ​ប្រើ​កម្មវិធី​ការ​តភ្ជាប់​​ឥត​បាន​ការ ។
Comment[ko]=Idle 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant Idle ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Idle tilkoblingsbehandler.
Comment[nds]=Topasst Kontoinstellen-Böversiet för Kontos, de den Verbinnenpleger „Idle“ bruukt
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Idle verbindingenbeheerder gebruiken.
Comment[nn]=Brukarflate for å setja oppkontoar med Idle tilkoplingshandsamar.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń Idle.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Idle.
Comment[pt_BR]=Interface de configuração de contas usando o gerenciador de conexões Idle.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Idle.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью менеджера соединений Idle.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Idle.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Idle.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Ајдл.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Ајдл.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Idle.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Idle.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Idle.
Comment[tr]=Idle bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштовування облікового запису за допомогою керування з’єднаннями Idle.
Comment[wa]=Eterface uzeu po-z apontyî a vosse môde les contes tot s' siervant do manaedjeu d' raloyaedje Idle.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Idle connection manager.xx
Comment[zh_CN]=通过 Idle 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Idle 連線管理員的帳號自訂帳號設定使用者介面。
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_idle
X-KDE-PluginInfo-Author=Lasse Liehu
X-KDE-PluginInfo-Email=lliehu@kolumbus.fi
X-KDE-PluginInfo-Name=idle
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true

==> ktp-accounts-kcm_22.08.1.orig.tar.xz: ktp-accounts-kcm-22.08.1/plugins/idle/ktpaccountskcm_plugin_idle.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Idle connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći Idle menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració del compte personalitzat per a comptes que usen el gestor de connexions Idle.
Comment[ca@valencia]=Interfície d'usuari de configuració del compte personalitzat per a comptes que utilitzen el gestor de connexions Idle.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Idle.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Idle.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Idle-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Idle.
Comment[en_GB]=Custom account configuration user interface for accounts using the Idle connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Idle.
Comment[et]=Idle ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[eu]=Kontuak konfiguratzeko norberak finkaturiko erabiltzaile interfazea «Idle» konexio kudeatzailea erabiltzen duten kontuetarako.
Comment[fi]=Idle-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « Idle ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Idle.
Comment[hu]=Egyedi beállítófelület az Idle kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Idle.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Idle.
Comment[kk]=Idle байланыс менеджерін қолданатын тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី​ផ្ទាល់ខ្លួន​សម្រាប់​គណនី​ដោយ​ប្រើ​កម្មវិធី​ការ​តភ្ជាប់​​ឥត​បាន​ការ ។
Comment[ko]=Idle 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant Idle ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Idle tilkoblingsbehandler.
Comment[nds]=Topasst Kontoinstellen-Böversiet för Kontos, de den Verbinnenpleger „Idle“ bruukt
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Idle verbindingenbeheerder gebruiken.
Comment[nn]=Brukarflate for å setja oppkontoar med Idle tilkoplingshandsamar.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń Idle.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Idle.
Comment[pt_BR]=Interface de configuração de contas usando o gerenciador de conexões Idle.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Idle.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью менеджера соединений Idle.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Idle.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Idle.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Ајдл.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Ајдл.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Idle.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Idle.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Idle.
Comment[tr]=Idle bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштовування облікового запису за допомогою керування з’єднаннями Idle.
Comment[wa]=Eterface uzeu po-z apontyî a vosse môde les contes tot s' siervant do manaedjeu d' raloyaedje Idle.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Idle connection manager.xx
Comment[zh_CN]=通过 Idle 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Idle 連線管理員的帳號自訂帳號設定使用者介面。
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_idle
X-KDE-PluginInfo-Author=Lasse Liehu
X-KDE-PluginInfo-Email=lliehu@kolumbus.fi
X-KDE-PluginInfo-Name=idle
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
